#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dice
version:              0.1.1
visibility:           public
id:                   dice-0.1.1-IZu4547rNB26BYfHzf5QwV
key:                  dice-0.1.1-IZu4547rNB26BYfHzf5QwV
license:              Unlicense
maintainer:           Naïm Favier <n@monade.li>
author:               James Cook <mokus@deepbondi.net>
stability:            work-in-progress
synopsis:             Simplistic D&D style dice-rolling system.
description:
    Simplistic D&D style dice-rolling system.

    > $ dice "2d10 + 2 * (d100 / d6)"
    > (5+2) + 2 * 64 / 2 => 71

category:             Game
abi:                  dcf91c3c3e90edf299b1d7b5b8aea825
exposed:              True
exposed-modules:      Data.Random.Dice
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dice-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dice
hs-libraries:         HSdice-0.1.1-IZu4547rNB26BYfHzf5QwV
depends:
    base-4.18.2.1 mtl-2.3.1 parsec-3.1.16.1
    random-1.2.1.3-Fpl3dUa1VuLH6jaWIu29Ly
    random-fu-0.3.0.1-JKnsaBc8cWn5UpnXzDI74v

haddock-interfaces:   /usr/share/doc/dice/html/dice.haddock
haddock-html:         /usr/share/doc/dice/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

